@@ -1,7 +1,4 @@
-#include <Rinternals.h>
-#include <Rdefines.h>
-#include <R.h>
-#include <Rmath.h>
+
 
 SEXP KR_table(SEXP Y, SEXP X);
 SEXP my_factor(SEXP sv);
